package ch.zhaw.projekt2.turnierverwaltung;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

public class TournamentDecorator implements IsObservable{
    private Tournament tournament;
    private FileIO fileIO;
    private List<IsObserver> listener = new ArrayList<>();

    public TournamentDecorator(FileIO fileIO, Tournament tournament){
        setTournament(tournament);
        setFileIO(fileIO);
    }

    public void setFileIO(FileIO fileIO) {
        this.fileIO = fileIO;
    }

    public void setTournament(Tournament tournament) {
        this.tournament = tournament;
    }

    @Override
    public void addListener(IsObserver observer) {
        listener.add(observer);
    }

    @Override
    public void removeListener(IsObserver observer) {
        listener.remove(observer);
    }

    public void createTournament(String name, Tournament.Type type){
        if(fileIO.tournamentExists(name)){
            System.out.println("Tournament with same name exists already.");
            return; //TODO handle and logging
        }
        try {
            Tournament tournament = new Tournament(name, type);
            fileIO.saveTournament(tournament);
            informListener();
        } catch (Tournament.InvalidNameException e) {
            e.printStackTrace(); //TODO handle and logging
        } catch (Tournament.InvalidTypeException e) {
            e.printStackTrace(); //TODO handle and logging
        } catch (IOException e) {
            e.printStackTrace(); //TODO handle and logging
        }
    }

    public void deleteTournament(FileIO.TournamentFile tournamentFile){
        try {
            fileIO.deleteTournament(tournamentFile);
            informListener();
        } catch (IOException e) {
            e.printStackTrace();  //TODO handle and logging
        }
    }


    public void informListener() {
        for(IsObserver observer : listener) {
            observer.update();
        }
    }
}
